@@ -47,7 +47,7 @@ ffgeom = from_dependency_import('ink_extensions.ffgeom')
 
 def version():    # Version number for this document
     """Return version number of this script"""
-    return "0.21" # Dated 2021-10-13
+    return "0.3" # Dated 2021-12-26
 
 __version__ = version()
 
@@ -310,6 +310,9 @@ def parseLengthWithUnits(string_to_parse):
     There is a more general routine to consider in scour.py if more
     generality is ever needed.
     """
+
+    if string_to_parse is None:
+        return None, None
     units = 'px'
     string = string_to_parse.strip()
     if string[-2:] == 'px':  # pixels, at a size of PX_PER_INCH per inch
@@ -344,14 +347,14 @@ def parseLengthWithUnits(string_to_parse):
     return value, units
 
 
-def unitsToUserUnits(input_string):
+def unitsToUserUnits(input_string, percent_ref=None):
     """
     Custom replacement for the unittouu routine in inkex.py
 
-    Parse the attribute into a value and associated units.
-    Return value in user units (typically "px").
+    Parse input_string into a value and units. Return value in user units (typically "px").
+    If input_string units are '%', then return (value * percent_ref / 100), where percent_ref
+    is a number corresponding to a length of 100% in in user units, e.g., document width.
     """
-
     value, unit = parseLengthWithUnits(input_string)
     if value is None:
         return None
@@ -364,15 +367,17 @@ def unitsToUserUnits(input_string):
     if unit == 'cm':
         return float(value) * PX_PER_INCH / 2.54
     if unit in ('Q', 'q'):
-        return float(value) * PX_PER_INCH / (40.0 * 2.54)
+        return float(value) * PX_PER_INCH / 101.6
     if unit == 'pc':
         return float(value) * PX_PER_INCH / 6.0
     if unit == 'pt':
         return float(value) * PX_PER_INCH / 72.0
     if unit == '%':
-        return float(value) / 100.0
-    # Unsupported units
-    return None
+        if percent_ref:
+            return float(value) * float(percent_ref) / 100.0
+        else:
+            return float(value) / 100.0
+    return None # Handle case of cnsupported units
 
 
 def position_scale (x_value, y_value, units_code):
